@@ -1,12 +1,12 @@
 use strict;
 use warnings;
 package Time::P;
-$Time::P::VERSION = '0.023';
+$Time::P::VERSION = '0.024';
 # ABSTRACT: Parse times from strings.
 
 use Carp qw/ croak /;
 use Exporter qw/ import /;
-use Function::Parameters;
+use Function::Parameters qw/ :lax /;
 use Data::Munge qw/ list2re /;
 use List::Util qw/ uniq /;
 
@@ -626,7 +626,7 @@ Time::P - Parse times from strings.
 
 =head1 VERSION
 
-version 0.023
+version 0.024
 
 =head1 SYNOPSIS
 
@@ -903,7 +903,7 @@ Equivalent to C<%H:%M:%S>, e.g. C<16:07:34>.
 
 =item C<%t>
 
-Arbitrary whitespace, like C<m/\s+/> - if uses as a formatting specifier rather than a parsing specifier, it will result in a C<\t> (i.e. a tab).
+Arbitrary whitespace, like C<m/\s+/> - if used as a formatting specifier rather than a parsing specifier, it will result in a C<\t> (i.e. a tab).
 
 =item C<%U>
 
